@@ -7,6 +7,11 @@ from requests import Response
 
 from knowledge.services import USER_AGENT_STR
 
+# Constants for header tags
+USER_AGENT_HEADER_FLAG: str = 'User-Agent'
+AUTHORIZATION_HEADER_FLAG: str = 'Authorization'
+CONTENT_TYPE_HEADER_FLAG: str = 'Content-Type'
+
 
 class WacomServiceException(Exception):
     """Exception thrown if Wacom service fails."""
@@ -65,7 +70,7 @@ class WacomServiceAPIClient(RESTAPIClient):
     USER_ENDPOINT: str = 'user'
     USER_LOGIN_ENDPOINT: str = f'{USER_ENDPOINT}/login'
 
-    def __init__(self, application_name: str, service_url: str, service_endpoint: str, verify_calls: bool = False):
+    def __init__(self, application_name: str, service_url: str, service_endpoint: str, verify_calls: bool = True):
         self.__application_name: str = application_name
         self.__service_endpoint: str = service_endpoint
         super().__init__(service_url, verify_calls)
@@ -93,11 +98,12 @@ class WacomServiceAPIClient(RESTAPIClient):
         """
         url: str = f'{self.service_url}/graph/{WacomServiceAPIClient.USER_LOGIN_ENDPOINT}/'
         headers: dict = {
-            'User-Agent': USER_AGENT_STR,
-            'x-tenant-api-key': tenant_key
+            USER_AGENT_HEADER_FLAG: USER_AGENT_STR,
+            'x-tenant-api-key': tenant_key,
+            'Content-Type': 'application/json'
         }
         payload: dict = {
-            'externalUserId': external_id
+            'ExternalUserId': external_id
         }
         response: Response = requests.post(url, headers=headers, json=payload, verify=self.verify_calls)
         if response.ok:
